@@ -6,7 +6,7 @@ from typing import Union
 from . import fileio, click_fix
 
 __app_name__ = "pie-manager"
-__version__ = "1.0.2"
+__version__ = "1.0.3"
 PATH = fileio.check_config()
 
 _ENTRY_POINT = 1
@@ -200,7 +200,7 @@ def unpkg(project:str, force):
                 Yaspin._show_cursor = _show_cursor
                 Yaspin._hide_cursor = _hide_cursor
 
-            with yaspin(text=f"{Fore.YELLOW}> Un-Packaging project{Fore.RESET}", color="blue", attrs=["bold"]) as sp:
+            with yaspin(sp, text=f"{Fore.YELLOW}> Un-Packaging project{Fore.RESET}", color="blue", attrs=["bold"]) as sp:
                 try:
                     os.rename(project, project[:-4] + ".zip")
 
@@ -306,7 +306,7 @@ def push(commit_message, remote, branch):
                     Yaspin._show_cursor = _show_cursor
                     Yaspin._hide_cursor = _hide_cursor
 
-                with yaspin(text=f"{Fore.YELLOW}> Pushing repository{Fore.RESET}", color="blue", attrs=["bold"]) as sp:
+                with yaspin(sp, text=f"{Fore.YELLOW}> Pushing repository{Fore.RESET}", color="blue", attrs=["bold"]) as sp:
                     
                     if subprocess.run(["git", "add", "."], stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL).returncode == 0:
                         sp.write(f"{Fore.GREEN}> Repository added to index{Fore.RESET}")
@@ -360,7 +360,7 @@ def new(name, short_description):
         Yaspin._show_cursor = _show_cursor
         Yaspin._hide_cursor = _hide_cursor
 
-    with yaspin(text=f"{Fore.YELLOW}> Creating project{Fore.RESET}", color="blue", attrs=["bold"]) as sp:
+    with yaspin(sp, text=f"{Fore.YELLOW}> Creating project{Fore.RESET}", color="blue", attrs=["bold"]) as sp:
         os.mkdir(name)
         os.mkdir(name + '/src')
 
@@ -436,6 +436,8 @@ def register_commands():
         for command in in_project_commands:
             if command == plist:
                 cmd = click.decorators.command(name="list")(command)
+            elif command == run:
+                cmd = click.command(name="run", context_settings=dict(ignore_unknown_options=True, allow_extra_args=True))(command)
             else:
                 cmd = click.decorators.command()(command)
             main.add_command(cmd)
